"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.login = exports.register = void 0;
const User_1 = __importDefault(require("../models/User"));
const bcryptjs_1 = __importDefault(require("bcryptjs"));
const error_1 = require("../utils/error");
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const register = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const salt = bcryptjs_1.default.genSaltSync(10);
        const hash = bcryptjs_1.default.hashSync(req.body.password, salt);
        const newUser = new User_1.default({
            username: req.body.username,
            email: req.body.email,
            hashPwd: hash,
        });
        yield newUser.save();
        res.status(200).json('Użytkownik został utworzony.');
    }
    catch (err) {
        next(err);
    }
});
exports.register = register;
const login = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const user = yield User_1.default.findOne({ username: req.body.username });
        if (!user)
            return next((0, error_1.createError)(404, "Użytkownik nie został znaleziony."));
        const isPassCorrect = yield bcryptjs_1.default.compare(req.body.password, user.hashPwd);
        if (!isPassCorrect)
            return next((0, error_1.createError)(400, "Nieprawidłowe hasło lub login."));
        const token = jsonwebtoken_1.default.sign({ id: user._id, isAdmin: user.isAdmin }, process.env.SECRET_KEY);
        const userResponse = {
            _id: user.id,
            username: user.username,
            email: user.email,
        };
        res
            .cookie('access_token', token, {
            secure: true,
            domain: process.env.DOMAIN,
            httpOnly: true,
        })
            .status(200)
            .json(userResponse);
    }
    catch (err) {
        next(err);
    }
});
exports.login = login;
//# sourceMappingURL=auth.controller.js.map