"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHotelRooms = exports.countByType = exports.countByCity = exports.getAllHotels = exports.getOneHotel = exports.deleteHotel = exports.updateHotel = exports.createHotel = void 0;
const Hotel_1 = __importDefault(require("../models/Hotel"));
const Room_1 = __importDefault(require("../models/Room"));
const createHotel = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const newHotel = new Hotel_1.default(req.body);
    try {
        const savedHotel = yield newHotel.save();
        res.status(200).json(savedHotel);
    }
    catch (err) {
        next(err);
    }
});
exports.createHotel = createHotel;
const updateHotel = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const updatedHotel = yield Hotel_1.default.findByIdAndUpdate(req.params.id, { $set: req.body }, { new: true });
        res.status(200).json(updatedHotel);
    }
    catch (err) {
        next(err);
    }
});
exports.updateHotel = updateHotel;
const deleteHotel = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield Hotel_1.default.findByIdAndDelete(req.params.id);
        res.status(200).json('Hotel został usunięty.');
    }
    catch (err) {
        next(err);
    }
});
exports.deleteHotel = deleteHotel;
const getOneHotel = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const hotel = yield Hotel_1.default.findById(req.params.id);
        res.status(200).json(hotel);
    }
    catch (err) {
        next(err);
    }
});
exports.getOneHotel = getOneHotel;
const getAllHotels = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const _a = req.query, { min, max, limit } = _a, others = __rest(_a, ["min", "max", "limit"]);
    try {
        const hotels = yield Hotel_1.default
            .find(Object.assign(Object.assign({}, others), { cheapestPrice: { $gt: min || 1, $lt: max || 999 } }))
            .limit(Number(limit));
        res.status(200).json(hotels);
    }
    catch (err) {
        next(err);
    }
});
exports.getAllHotels = getAllHotels;
const countByCity = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    let cities = req.query.cities;
    if (typeof cities === 'string') {
        cities = cities.split(',');
    }
    try {
        let list;
        if (Array.isArray(cities)) {
            list = yield Promise.all(cities.map(city => {
                return Hotel_1.default.countDocuments({ city: city });
            }));
        }
        res.status(200).json(list);
    }
    catch (err) {
        next(err);
    }
});
exports.countByCity = countByCity;
const countByType = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const hotelCount = yield Hotel_1.default.countDocuments({ type: 'hotel' });
        const apartmentCount = yield Hotel_1.default.countDocuments({ type: 'apartament' });
        const resortCount = yield Hotel_1.default.countDocuments({ type: 'resort' });
        const villaCount = yield Hotel_1.default.countDocuments({ type: 'rezydencja' });
        res.status(200).json([
            hotelCount, apartmentCount, resortCount, villaCount,
        ]);
    }
    catch (err) {
        next(err);
    }
});
exports.countByType = countByType;
const getHotelRooms = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const hotel = yield Hotel_1.default.findById(req.params.id);
        const list = yield Promise.all(hotel.rooms.map(room => {
            return Room_1.default.findById(room);
        }));
        res.status(200).json(list);
    }
    catch (err) {
        next(err);
    }
});
exports.getHotelRooms = getHotelRooms;
//# sourceMappingURL=hotel.controller.js.map