"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAllRooms = exports.getOneRoom = exports.deleteRoom = exports.updateRoomAvailability = exports.updateRoom = exports.createRoom = void 0;
const Room_1 = __importDefault(require("../models/Room"));
const Hotel_1 = __importDefault(require("../models/Hotel"));
const createRoom = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const hotelId = req.params.hotelId;
    const newRoom = new Room_1.default(req.body);
    try {
        const savedRoom = yield newRoom.save();
        try {
            yield Hotel_1.default.findByIdAndUpdate(hotelId, {
                $push: { rooms: savedRoom._id },
            });
        }
        catch (err) {
            next(err);
        }
        res.status(200).json(savedRoom);
    }
    catch (err) {
        next(err);
    }
});
exports.createRoom = createRoom;
const updateRoom = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const updatedRoom = yield Room_1.default.findByIdAndUpdate(req.params.id, { $set: req.body }, { new: true });
        res.status(200).json(updatedRoom);
    }
    catch (err) {
        next(err);
    }
});
exports.updateRoom = updateRoom;
const updateRoomAvailability = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield Room_1.default.updateOne({ 'roomNumbers._id': req.params.id }, {
            $push: {
                'roomNumbers.$.unavailableDates': req.body.dates,
            }
        });
        res.status(200).json('ok');
    }
    catch (err) {
        next(err);
    }
});
exports.updateRoomAvailability = updateRoomAvailability;
const deleteRoom = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const hotelId = req.params.hotelId;
    try {
        yield Room_1.default.findByIdAndDelete(req.params.id);
        try {
            yield Hotel_1.default.findByIdAndUpdate(hotelId, {
                $pull: { rooms: req.params.id },
            });
        }
        catch (err) {
            next(err);
        }
        res.status(200).json('Pokój został usunięty.');
    }
    catch (err) {
        next(err);
    }
});
exports.deleteRoom = deleteRoom;
const getOneRoom = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const room = yield Room_1.default.findById(req.params.id);
        res.status(200).json(room);
    }
    catch (err) {
        next(err);
    }
});
exports.getOneRoom = getOneRoom;
const getAllRooms = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const rooms = yield Room_1.default.find();
        res.status(200).json(rooms);
    }
    catch (err) {
        next(err);
    }
});
exports.getAllRooms = getAllRooms;
//# sourceMappingURL=room.controller.js.map